@@ -558,6 +558,9 @@ Commands for multiple targets will be running async, but
 commands order is preserved for device (and is running on same connection),
 exit on first fail unless retry options provided.
 
+You may use jinja2 templating engine to {% include "other_script" %}
+or {{ VAR_KEY }} rendering in combination with --var VAR_KEY VAR_VALUE options.
+
 It\'s highly recommended to use sleep option for virtual_remote!
 
 \b
@@ -571,14 +574,14 @@ command1 [ARGS]...
 command2 [ARGS]...
 
 \b
-Example: samsung-mdc ./targets.txt script -s 3 -r 1 ./commands.txt
+Example: samsung-mdc ./targets.txt script -s 3 -r 1 -v KEY enter ./commands.txt
 # commands.txt content
 power on
 sleep 5
 clear_menu
 virtual_remote key_menu
 virtual_remote key_down
-virtual_remote enter
+virtual_remote {{ KEY }}
 clear_menu
 """
 
@@ -596,20 +599,38 @@ clear_menu
               help='Sleep before script retry (seconds)')
 @click.option('--ignore-nak', is_flag=True,
               help='Ignore negative acknowledgement errors')
+@click.option('--var', '-v', multiple=True, nargs=2, type=(str, str),
+              help='Variable "{{ NAME }}" in script will be replaced by VALUE',
+              metavar='NAME VALUE')
 @click.argument('script_file', type=click.File(),
                 help='Text file with commands, separated by newline.',
                 cls=ArgumentWithHelp)
 @click.pass_context
 def script(ctx, script_file, sleep, retry_command, retry_command_sleep,
-           retry_script, retry_script_sleep, ignore_nak):
+           retry_script, retry_script_sleep, ignore_nak, var):
     import shlex
 
+    var = dict(var)
     retry_command_sleep = retry_command_sleep or sleep
     retry_script_sleep = retry_script_sleep or sleep
+    script_content = script_file.read()
+
+    if var or '{{' in script_content or '{%' in script_content:
+        from jinja2 import Environment, FileSystemLoader, StrictUndefined
+
+        class RelativeEnvironment(Environment):
+            def join_path(self, template, parent):
+                # Allowing include based on path relative to script
+                return os.path.join(os.path.dirname(parent), template)
+
+        env = RelativeEnvironment(loader=FileSystemLoader(['/', './']),
+                                  undefined=StrictUndefined)
+        template = env.get_template(script_file.name)
+        script_content = template.render(**var)
 
     def fail(lineno, line, reason):
         raise click.UsageError(
-            f'{script_file.name}:{lineno}: "{line}": {reason}')
+            f'{script_file.name}:{lineno}:"{line}": {reason}')
 
     def create_disconnect():
         async def disconnect(connection, display_id):
@@ -629,11 +650,13 @@ def script(ctx, script_file, sleep, retry_command, retry_command_sleep,
 
     lines = [
         (i + 1, line.strip())
-        for i, line in enumerate(script_file.read().split('\n'))
-        if line.strip() and not line.strip().startswith('#')
+        for i, line in enumerate(script_content.splitlines())
     ]
     calls = []
     for lineno, line in lines:
+        if not line or line.startswith('#'):
+            continue
+
         command, *args = shlex.split(line)
         command = command.lower()
         if (command not in cli.commands
